==> ns-jckj-biz-2.0.0-20250717.101719-13-sources.jar: com/geoway/jckj/biz/entity/SysOrganization.java <==
package com.geoway.jckj.biz.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.geoway.jckj.base.enums.UserSysEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * 
 * @TableName sys_organization
 */
@TableName(value ="sys_organization")
@Data
public class SysOrganization extends SaasEntity implements Serializable {

    public SysOrganization(){
        this.source=UserSysEnum.JCKJ.value;
    }
    /**
     * 
     */
    @TableId(value = "f_id", type = IdType.ASSIGN_UUID)
    private String id;

    /**
     * 
     */
    @TableField(value = "f_name")
    private String name;

    /**
     * 
     */
    @TableField(value = "f_aname")
    private String aname;

    /**
     * 
     */
    @TableField(value = "f_code")
    private String code;

    /**
     * 
     */
    @TableField(value = "f_level")
    private Integer level;

    /**
     * 
     */
    @TableField(value = "f_pid")
    private String pid;

    /**
     * 
     */
    @TableField(value = "f_sort")
    private Integer sort;

    /**
     * 
     */
    @TableField(value = "f_leader")
    private Long leader;
    /**
     *
     */
    @TableField(value = "f_id_path")
    private String idpath;

    /**
     * 组织机构来源
     */
    @TableField(value = "f_source")
    private String source= UserSysEnum.JCKJ.value;
    /**
     * 
     */
    @TableField(value = "f_bz")
    private String bz;

    @TableField(exist = false)
    private String allname;

    @TableField(exist = false)
    private int childCount;

    @TableField(exist = false)
    private Boolean editable;

    @TableField(exist = false)
    private List<SysOrganization> children;

    @TableField(exist = false)
    private  List<SysUser> bindUsers;

    @TableField(exist = false)
    private static final long serialVersionUID = 1L;

}

==> ns-jckj-biz-2.0.0-20250827.152430-21-sources.jar: com/geoway/jckj/biz/entity/SysOrganization.java <==
package com.geoway.jckj.biz.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.geoway.jckj.biz.enums.UserSysEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * 
 * @TableName sys_organization
 */
@TableName(value ="sys_organization")
@Data
public class SysOrganization extends SaasEntity implements Serializable {

    public SysOrganization(){
        this.source=UserSysEnum.JCKJ.value;
    }
    /**
     * 
     */
    @TableId(value = "f_id", type = IdType.ASSIGN_UUID)
    private String id;

    /**
     * 
     */
    @TableField(value = "f_name")
    private String name;

    /**
     * 
     */
    @TableField(value = "f_aname")
    private String aname;

    /**
     * 
     */
    @TableField(value = "f_code")
    private String code;

    /**
     * 
     */
    @TableField(value = "f_level")
    private Integer level;

    /**
     * 
     */
    @TableField(value = "f_pid")
    private String pid;

    /**
     * 
     */
    @TableField(value = "f_sort")
    private Integer sort;

    /**
     * 
     */
    @TableField(value = "f_leader")
    private Long leader;
    /**
     *
     */
    @TableField(value = "f_id_path")
    private String idpath;

    /**
     * 组织机构来源
     */
    @TableField(value = "f_source")
    private String source= UserSysEnum.JCKJ.value;
    /**
     * 
     */
    @TableField(value = "f_bz")
    private String bz;

    @TableField(exist = false)
    private String allname;

    @TableField(exist = false)
    private int childCount;

    @TableField(exist = false)
    private Boolean editable;

    @TableField(exist = false)
    private List<SysOrganization> children;

    @TableField(exist = false)
    private  List<SysUser> bindUsers;

    @TableField(exist = false)
    private static final long serialVersionUID = 1L;

}
